Checks whether a VRT file is suitable for conversion to a GTI tile index. A "simple" VRT mosaic must satisfy:
validate_vrt(vrt_info)A list as returned by parse_vrt().
Invisibly, TRUE if valid. Throws an error with a diagnostic
message if validation fails.
All sources are SimpleSource or ComplexSource (no AveragedSource,
KernelFilteredSource, etc.)
No subClass on bands (no VRTWarpedDataset, VRTDerivedRasterBand)
All bands reference the same set of source files with the same DstRect layout (standard multi-band mosaic)
SrcRect and DstRect dimensions match (no within-VRT resampling)
if (FALSE) { # \dontrun{
info <- parse_vrt("mosaic.vrt")
validate_vrt(info)
} # }